@@ -5,17 +5,18 @@ prep
 Main callable module
 """
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 import os, re, sys, time, socket
 import subprocess
 import ConfigParser
-import argparse
 
 _conf_file = 'prep.cfg'
 _conf_sections = ['prep', 'pre', 'post', 'files', 'vars']
 
 def prep():
+    # Lazy import so setup.py can load the version directly from this module
+    import argparse
     parser = argparse.ArgumentParser()
     parser.add_argument('-m', '--mode', nargs='?', help='Preparation mode (can also specify as --MODE)')
     parser.add_argument('-H', '--host', default=socket.gethostname(), nargs='?', help='Hostname to prepare for')
@@ -141,12 +142,12 @@ def _load_conf(dirpath, args):
                 #print section[len(key)+1:]
                 (type,value) = section[len(key)+1:].split('=', 2)
                 if type == 'mode':
-                    if value == args.mode:
+                    if value.lower() == args.mode.lower():
                         conf[key] = _smart_merge(conf[key], parser.items(section))
                         #print "ADD SECTION "+section
                         #print parser.items(section)
                 elif type =='host':
-                    if args.host == value or args.host.startswith(value + '.'):
+                    if args.host.lower() == value.lower() or args.host.lower().startswith(value.lower() + '.'):
                         conf[key] = _smart_merge(conf[key], parser.items(section))
                         #print "ADD SECTION "+section
                         #print parser.items(section)
@@ -155,6 +156,11 @@ def _load_conf(dirpath, args):
                             conf[key] = _smart_merge(conf[key], parser.items(section))
                             #print "ADD SECTION "+section
                             #print parser.items(section)
+                if type == 'user':
+                    if value.lower() == os.environ['USER'].lower():
+                        conf[key] = _smart_merge(conf[key], parser.items(section))
+                        #print "ADD SECTION "+section
+                        #print parser.items(section)
                 else:
                     raise ValueError('Invalid configuration section "{0}" in "{1}"'.format(type, section))
     # Expand certain data types for pre and post conf items
